module.exports = {
  description: 'Blueprint for @choiceform/ui-foundation',

  normalizeEntityName(entityName) {
    return entityName;
  },

  afterInstall: function(options) {
    const isAddon = options.project.isEmberCLIAddon();

    const targetName = isAddon ? 'addon' : 'app';
    this.ui.writeInfoLine(`Installing dependencies for ${targetName} ...`);
    this.ui.writeInfoLine(`正在为 ${targetName} 安装依赖...`);

    const blueprintOptions = { save: isAddon };
    return this.addAddonsToProject({
      packages: [
        'ember-cli-autoprefixer',
        'ember-cli-dependency-checker',
        'ember-decorators',
        'ember-qunit-decorators',
      ],
    })
      .then(() =>
        this.addAddonToProject({
          name: 'ember-css-modules',
          bpOptions: blueprintOptions,
        })
      )
      .then(() =>
        this.addAddonToProject({
          name: 'ember-lifeline',
          bpOptions: blueprintOptions,
        })
      )
      .then(() =>
        this.addAddonToProject({
          name: 'ember-cli-typescript',
          bpOptions: blueprintOptions,
        })
      )
      .then(() =>
        this.addPackagesToProject([
          { name: 'eslint-plugin-qunit' },
          { name: '@typescript-eslint/parser' },
          { name: '@typescript-eslint/eslint-plugin' },
        ])
      )
      .then(() =>
        this.removePackageToProject('ember-cli-typescript-blueprints')
      )
      .then(() => {
        this.ui.writeLine(`For ${targetName} usage, please run:`);
        this.ui.writeLine(`用于 ${targetName}，请运行：`);
        this.ui.writeInfoLine(`ember generate foundation-for-${targetName}`);
      });
  },
};
